@@ -11,7 +11,7 @@ import sys
 import argparse
 from pyThorlabsPM100x.driver import ThorlabsPM100x
 from pyThorlabsPM100x.plots import PlotObject
-from pyThorlabsPM100x.abstract_interface import abstract_interface
+from pyThorlabsPM100x.abstract_interface import abstract_interface, abstract_gui
 
 graphics_dir = os.path.join(os.path.dirname(__file__), 'graphics')
 
@@ -29,9 +29,6 @@ class interface(abstract_interface):
         The pyqt5 QApplication() object
     mainwindow  : Qt.QWidget
         The main window of the Qt application
-    parent : Qt.QWidget      
-        a QWidget (or QMainWindow) object that will be the parent for the gui of this device.
-        When this script is ran on its own (i.e. not within another gui) self.mainwindow and self.parent are actually the same object
     instrument : ThorlabsPM100x
         a driver object, for the low-level communication with the device
     gui : gui()
@@ -115,17 +112,12 @@ class interface(abstract_interface):
         '''
             parent, QWidget        
                 a QWidget (or QMainWindow) object that will be the parent for the gui of this device.
-                When this script is ran on its own (i.e. not within another gui) self.mainwindow and self.parent are actually the same object
+                When this script is ran on its own (i.e. not within another gui) self.mainwindow and parent are actually the same object
             plot, boolean
                 If set true, the GUI also generates a plot object (and a button to show/hide the plot) to plot the content of the self.stored_data object
         '''
-        super().create_gui(parent)
-        self.gui = gui(self,plot)
-        self.gui.initialize()
-        self.parent.setLayout(self.gui.container) 
-        #self.parent.layout().setSizeConstraint(Qt.QLayout.SetFixedSize)
-        self.parent.resize(self.parent.minimumSize())
-
+        self.gui = gui(self,parent,plot)
+        self.gui.initialize() 
 
 ### Functions to talk with low-level driver
 
@@ -355,9 +347,10 @@ class interface(abstract_interface):
     ### END Functions to talk with low-level driver
     
     
-class gui():
-    def __init__(self,interface,plot=False):
-        self.interface = interface
+class gui(abstract_gui):
+    def __init__(self,interface,parent,plot=False):
+        super().__init__(interface,parent)
+
         self.widgets_enabled_when_connected = []     #The widgets in this list will only be enabled when the interface has succesfully connected to a device
         self.widgets_enabled_when_disconnected = []  #The widgets in this list will only be enabled when the interface is not connected to a device
         self.plot_window = None # QWidget object of the widget (i.e. floating window) that will contain the plot
@@ -480,6 +473,7 @@ class gui():
             self.create_plot()
     
     def initialize(self):
+        super().initialize()
         self.click_button_refresh_list_devices()    #By calling this method, as soon as the gui is created we also look for devices
         self.set_disconnected_state()               #When GUI is created, all widgets are set to the "Disconnected" state
         
@@ -574,8 +568,7 @@ class MainWindow(Qt.QWidget):
     def __init__(self):
         super().__init__()
         self.setWindowTitle(__package__)
-        # Set the central widget of the Window.
-        # self.setCentralWidget(self.container)
+
     def closeEvent(self, event):
         if self.child:
             self.child.close()
